@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 class RedPacketConfig(object):
     def __init__(self, red_packet_switch=True, heartbeat=True, smart_mode=True, threshold=0.5, adventure_mode=True,
                  timeout=7, rate=3, rps_limit=100):
@@ -20,7 +21,7 @@ class AuthConfig(object):
 
 class ChatConfig(object):
     def __init__(self, blacklist=[], repeat_mode_switch=False, frequency=5, soliloquize_switch=False,
-                 soliloquize_frequency=20, sentences=[], answerMode :bool=False):
+                 soliloquize_frequency=20, sentences=[], answer_mode: bool = False):
         self.repeat_mode_switch = repeat_mode_switch
         self.frequency = frequency
         self.soliloquize_switch = soliloquize_switch
@@ -28,14 +29,23 @@ class ChatConfig(object):
         self.sentences = ['你们好！', '牵着我的手，闭着眼睛走你也不会迷路。',
                           '吃饭了没有?', '💗 爱你哟！'] + sentences
         self.blacklist = blacklist
-        self.answerMode = answerMode
+        self.answer_mode = answer_mode
 
 
 class Config(object):
-    def __init__(self, auth: AuthConfig = None, redpacket: RedPacketConfig = None, chat: ChatConfig = None, cfg_path :str = None):
+    def __init__(self, auth: AuthConfig = None, redpacket: RedPacketConfig = None, chat: ChatConfig = None, cfg_path: str = None):
         self.auth_config = auth
         self.redpacket_config = redpacket
         self.chat_config = chat
         self.cfg_path = cfg_path
 
+
+class CliConfig(object):
+    def __init__(self, username: str = '', password: str = '', code: str = '', file_path: str = None):
+        self.username = username
+        self.password = password
+        self.code = code
+        self.file_path = file_path
+
+
 GLOBAL_CONFIG = Config()
