@@ -1,8 +1,12 @@
-from src.api import FishPi
+# -*- coding: utf-8 -*-
+
+import enum
 import json
 import time
-import enum
-from src.utils.utils import RPS_LOSED, RPS_ZERO, RPS_SUCCESS
+
+from src.api import FishPi
+from src.utils.utils import RPS_LOSED, RPS_SUCCESS, RPS_ZERO
+
 from .config import GLOBAL_CONFIG
 
 CODE = enum.Enum('REDPACKET_CODE', ['SUCCESS', 'LOSED', 'NOT_ME', "ZERO"])
@@ -11,17 +15,16 @@ CODE = enum.Enum('REDPACKET_CODE', ['SUCCESS', 'LOSED', 'NOT_ME', "ZERO"])
 def __open_redpacket_render(username, redpacket: dict) -> CODE:
     who = redpacket['who']
     sender = redpacket['info']['userName']
-    for i in who:
-        if i['userName'] == username:
-            if i['userMoney'] < 0:
-                print(f"红包助手: 悲剧，你竟然被{sender}反向抢了红包({str(i['userMoney'])})积分!")
-                return CODE.LOSED
-            elif i['userMoney'] == 0:
-                print(f"红包助手: 零溢事件，{sender}的红包抢到了({str(i['userMoney'])})积分!")
-                return CODE.ZERO
-            else:
-                print(f"红包助手: 恭喜，你抢到了{sender}的红包({str(i['userMoney'])})积分!")
-                return CODE.SUCCESS
+    for i in (user for user in who if user['userName'] == username):
+        if i['userMoney'] < 0:
+            print(f"红包助手: 悲剧，你竟然被{sender}反向抢了红包({str(i['userMoney'])})积分!")
+            return CODE.LOSED
+        elif i['userMoney'] == 0:
+            print(f"红包助手: 零溢事件，{sender}的红包抢到了({str(i['userMoney'])})积分!")
+            return CODE.ZERO
+        else:
+            print(f"红包助手: 恭喜，你抢到了{sender}的红包({str(i['userMoney'])})积分!")
+            return CODE.SUCCESS
     print(f"红包助手: 遗憾 {sender}的红包没有抢到，比别人慢了一点点，建议换宽带!")
     return CODE.NOT_ME
 
@@ -48,17 +51,30 @@ def open_rock_paper_scissors_packet(api: FishPi, red_packet_id) -> None:
         api.chatroom.send(RPS_ZERO)
 
 
+def render_redpacket(api: FishPi, message: dict) -> None:
+    if message['type'] != 'redPacketStatus':
+        return
+    sender = message['whoGive']
+    goter = message['whoGot']
+    if sender == api.current_user:
+        if goter != sender:
+            print(f"红包助手: {goter} 领取了你的红包!")
+    else:
+        return
+
+
 def rush_redpacket(api: FishPi, redpacket):
     sender = redpacket['userName']
+    content = json.loads(redpacket['content'])
     if sender == api.current_user:
         print('\t\t\t\t\t\t[' + redpacket['time'] + ']')
         print('\t\t\t\t\t\t发送了一个红包')
+        if content['type'] not in ['rockPaperScissors', 'heartbeat']:
+            open_red_packet(api, redpacket['oId'])
         return
     if (GLOBAL_CONFIG.redpacket_config.red_packet_switch == False):
         print(f'红包助手: {sender}发送了一个红包 你错过了这个红包，请开启抢红包模式！')
         return
-    sender = redpacket['userName']
-    content = json.loads(redpacket['content'])
     if content['type'] == 'heartbeat':
         if GLOBAL_CONFIG.redpacket_config.heartbeat:
             if GLOBAL_CONFIG.redpacket_config.smart_mode:
@@ -90,10 +106,11 @@ def __analyzeHeartbeatRedPacket(api: FishPi, red_packet_id):
     for data in api.chatroom.more()['data']:
         if data['oId'] == red_packet_id:
             if data['content']:
-                __analyze(api, json.loads(data['content']), red_packet_id, data['time'], data['userName'])
+                __analyze(api, json.loads(
+                    data['content']), red_packet_id, data['time'], data['userName'])
             else:
                 return
-        return    
+        return
     print("红包助手: 你与此红包无缘")
 
 
@@ -105,10 +122,9 @@ def __analyze(api: FishPi, packet, red_packet_id, ctime, sender):
         return
 
     probability = 1 / (count - got)
-    for get in packet['who']:
-        if get['userMoney'] > 0:
-            print('红包助手: '+sender+' 发送的心跳红包已无效，智能跳坑！')
-            return
+    for _ in (x for x in packet['who'] if x['userMoney'] > 0):
+        print('红包助手: '+sender+' 发送的心跳红包已无效，智能跳坑！')
+        return
     print(f'红包助手: 此心跳红包的中奖概率为:{str(probability)}')
     if probability >= GLOBAL_CONFIG.redpacket_config.threshold:
         open_red_packet(api, red_packet_id)
