@@ -1,31 +1,22 @@
 # -*- coding: utf-8 -*-
 import click
-from src.core import __init__
-from src.core.config import GLOBAL_CONFIG, AuthConfig
-from src.core.user import login, auto_check_in
-from src.core.cli import cli_handler
+
+from src.api import API
+from src.core import init_config
+from src.core.command import init_cli
+from src.core.config import CliConfig
+from src.core.user import check_in, login
 from src.core.websocket import init_chatroom
 from src.utils.version import __version__
-from src.api import API
-
-
-class CliConfig(object):
-    def __init__(self, username: str = '', password: str = '', code: str = '', file_path: str = None):
-        self.username = username
-        self.password = password
-        self.code = code
-        self.file_path = file_path
 
 
 def run(config: CliConfig):
-    __init__(API, config.file_path)
-    if config.username is not None and config.password is not None:
-        GLOBAL_CONFIG.auth_config = AuthConfig(
-            config.username, config.password, config.code)
+    init_config(API, config)
     login(API)
-    auto_check_in(API)
+    check_in(API)
     init_chatroom(API)
-    cli_handler(API)
+    init_cli((API))
+
 
 @click.command()
 @click.version_option(__version__)
